@@ -202,15 +202,24 @@ class BaseRun(DataMixin, models.Model):
         Instance = get_instance_model()
         return Instance.objects.filter(run=self)
 
+    @cached_property
+    def running_instances(self) -> List[BaseInstance]:
+        return [
+            instance
+            for instance in self.instances
+            if instance.date_start and not instance.date_end
+        ]
+
+    @cached_property
+    def ended_instances(self) -> List[BaseInstance]:
+        return [instance for instance in self.instances if instance.date_end]
+
     @cached_property
     def ended(self):
         if self.completed:
             return True
-        instances = self.instances.count()
-        return (
-            instances > 0
-            and self.instances.filter(date_end__isnull=False).count() == instances
-        )
+        instances_count = len(self.instances)
+        return instances_count > 0 and len(self.ended_instances) == instances_count
 
     def prepare(self) -> List[BaseInstance]:
         """
@@ -419,13 +428,14 @@ class BaseInstance(DataMixin, models.Model):
     def get_play_url(self):
         return ""
 
-    def finish_character(self, character: BaseCharacterData):
-        assert character.instance_id == self.id
-        character.finish()
+    def finish_characters(self, *characters: List[BaseCharacterData]):
+        for character in characters:
+            assert character.instance_id == self.id
+            character.finish()
 
-        characters = self.character_set.exclude(user=None)
-        total = characters.count()
-        finished = characters.exclude(_date_finished=None).count()
+        all_characters = self.character_set.exclude(user=None)
+        total = all_characters.count()
+        finished = all_characters.exclude(_date_finished=None).count()
         if total and total == finished:
             self.date_end = timezone.now()
             self.save()
